@@ -318,8 +318,10 @@ def load_daily_all(period='1min',
 
     with open(file_path, 'w') as new_file:
         for item in list_file(download_dir2, deep=10):
+            symbol = os.path.basename(item).split('-')[0]
             for txt in open(item, 'r'):
-                new_file.write(txt)
+                txt.replace('\n', f'\n{symbol},')
+                new_file.write(f'{symbol},{txt}')
 
     if delete_file:
         removedirs(download_dir2)
@@ -354,7 +356,7 @@ def load_symbol_all(symbol='SHIBUSDT',
 
 def load_symbol_all_to_db(symbol='SHIBUSDT',
                           start_date=datetime(2021, 5, 1),
-                          end_date=datetime(2021, 5, 23), ):
+                          end_date=datetime(2021, 5, 3) ):
     history = SymbolHistory(symbol=symbol)
     history.run(start_date=start_date, end_date=end_date)
     return history.db_path
