@@ -1,6 +1,6 @@
+import pandas as pd
 import xgboost as xgb
 from notecoin.huobi.model import BaseModel
-from sklearn.multioutput import MultiOutputRegressor
 
 
 class XgboostModel(BaseModel):
@@ -77,9 +77,11 @@ class MultiXgboostModel(BaseModel):
 
         if train:
             cols = []
+            df2['open2'] = df2['open'] - df2['open'].shift()
+            df2['open2'] = df2['open2'].apply(lambda x: 1 if x > 0 else 0)
             for window in self.windows:
                 col = f'label{window}'
-                df2[col] = df2['open'].shift(window)
+                df2[col] = df2['open2'].shift(window)
                 cols.append(col)
 
             df2.dropna(axis=0, how='any', inplace=True)
@@ -93,10 +95,13 @@ class MultiXgboostModel(BaseModel):
 
     def train(self, df, *args, **kwargs):
         x, y = self.solve(df)
-        other_params = {'learning_rate': 0.1, 'n_estimators': 300, 'max_depth': 5, 'min_child_weight': 1, 'seed': 0,
-                        'subsample': 0.8, 'colsample_bytree': 0.8, 'gamma': 0, 'reg_alpha': 0, 'reg_lambda': 1}
 
-        self.model = MultiOutputRegressor(xgb.XGBClassifier(objective='reg:squarederror', **other_params)).fit(x, y)
+        from sklearn.multiclass import OneVsRestClassifier
+        from xgboost import XGBClassifier
+
+        self.model = OneVsRestClassifier(
+            XGBClassifier(eval_metric=['logloss', 'auc', 'error'], use_label_encoder=False))
+        self.model.fit(x, y)
 
     def predict(self, df, *args, **kwargs):
         x = self.solve(df, train=False)
